VoxaAnimationConfig class
Constructors
- VoxaAnimationConfig({Duration defaultDuration = const Duration(milliseconds: 300), bool reducedMotion = false})
-
const
-
VoxaAnimationConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- defaultDuration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- reducedMotion → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Duration? defaultDuration, bool? reducedMotion}) → VoxaAnimationConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited