VoxaThemeController class
- Inheritance
-
- Object
- AnyNotifier<
VoxaThemeConfig, VoxaThemeConfig> - VoxaThemeController
- Annotations
-
- @riverpod
Constructors
Properties
- darkTheme → ThemeData
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- lightTheme → ThemeData
-
no setter
- ref → Ref
-
The Ref associated with this notifier.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ VoxaThemeConfig
-
The value currently exposed by this notifier.
getter/setter pairinherited
- stateOrNull → VoxaThemeConfig?
-
The value currently exposed by this Notifier.
no setterinherited
- themeData → ThemeData
-
no setter
Methods
-
build(
) → VoxaThemeConfig -
init(
) → Future< void> -
listenSelf(
void listener(VoxaThemeConfig? previous, VoxaThemeConfig next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener -
Listens to changes on the value exposed by this provider.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runBuild(
) → void -
Executes Notifier.build.
inherited
-
setThemeMode(
ThemeMode mode) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateConfig(
VoxaThemeConfig config) → void -
updateShouldNotify(
VoxaThemeConfig previous, VoxaThemeConfig next) → bool -
A method invoked when the state exposed by this Notifier changes.
It compares the previous and new value, and return whether listeners
should be notified.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited